Size

Enum Size 

pub enum Size {
    Known(u64),
    Unknown,
}

Variants



Known(u64)



Unknown

Implementations

Source

impl Size

pub fn is_known(&self) -> bool

Returns true if the size is known and false otherwise.

pub fn is_unknown(&self) -> bool

Returns true if the size is unknown and false otherwise.

pub fn value(&self) -> Option<u64>

Returns the size if known, otherwise returns None.