DeleteObjectsStreaming

Struct DeleteObjectsStreaming 

pub struct DeleteObjectsStreaming { /* private fields */ }
Argument builder for streaming multiple object deletions using the DeleteObjects S3 API operation.

This struct constructs the parameters required for the delete_objects_streaming method.

Implementations

Source

impl DeleteObjectsStreaming

pub fn new( client: MinioClient, bucket: BucketName, objects: impl Into<ObjectsStream>, ) -> Self

pub fn bypass_governance_mode(self, bypass_governance_mode: bool) -> Self

pub fn verbose_mode(self, verbose_mode: bool) -> Self

Enables verbose mode (defaults to false).

If enabled, the response will include the keys of objects that were successfully deleted. Otherwise, only objects that encountered an error are returned.

pub fn extra_headers(self, extra_headers: Option<Multimap>) -> Self

pub fn extra_query_params(self, extra_query_params: Option<Multimap>) -> Self

pub fn region(self, region: Option<Region>) -> Self

Sets the region for the request.