pub struct StatObjectResponse { /* private fields */ }Expand description
Response from the stat_object API.
Provides metadata about an object stored in S3 or a compatible service.
Implementations
Sourceimpl StatObjectResponse
impl StatObjectResponse
Sourcepub fn size(&self) -> Result<u64, ValidationErr>
pub fn size(&self) -> Result<u64, ValidationErr>
Returns the size of the object (header-value of Content-Length).
Sourcepub fn last_modified(&self) -> Result<Option<UtcTime>, ValidationErr>
pub fn last_modified(&self) -> Result<Option<UtcTime>, ValidationErr>
Returns the last modified time of the object (header-value of Last-Modified).
Sourcepub fn retention_mode(&self) -> Result<Option<RetentionMode>, ValidationErr>
pub fn retention_mode(&self) -> Result<Option<RetentionMode>, ValidationErr>
Returns the retention mode of the object (header-value of x-amz-object-lock-mode).
Sourcepub fn retention_retain_until_date(
&self,
) -> Result<Option<UtcTime>, ValidationErr>
pub fn retention_retain_until_date( &self, ) -> Result<Option<UtcTime>, ValidationErr>
Returns the retention date of the object (header-value of x-amz-object-lock-retain-until-date).
Sourcepub fn legal_hold(&self) -> Result<Option<bool>, ValidationErr>
pub fn legal_hold(&self) -> Result<Option<bool>, ValidationErr>
Returns the legal hold status of the object (header-value of x-amz-object-lock-legal-hold).
Sourcepub fn user_metadata(&self) -> Result<HashMap<String, String>, ValidationErr>
pub fn user_metadata(&self) -> Result<HashMap<String, String>, ValidationErr>
Returns the user-defined metadata of the object (header-value of x-amz-meta-*).